@@ -131,9 +131,9 @@ char **make_exclude_list(char *fname,char **list1,int fatal)
 }
 
 
-void add_exclude_file(char *fname)
+void add_exclude_file(char *fname,int fatal)
 {
-  exclude_list = make_exclude_list(fname,exclude_list,1);
+  exclude_list = make_exclude_list(fname,exclude_list,fatal);
 }
 
 
@@ -183,7 +183,7 @@ void add_cvs_excludes(void)
 
   if ((p=getenv("HOME"))) {
     sprintf(fname,"%s/.cvsignore",p);
-    add_exclude_file(fname);
+    add_exclude_file(fname,0);
   }
 
   if ((p=getenv("CVSIGNORE"))) {
