@@ -37,6 +37,7 @@ int preserve_times = 0;
 int update_only = 0;
 int cvs_exclude = 0;
 int dry_run=0;
+int local_server=0;
 
 int am_server = 0;
 static int sender = 0;
@@ -136,23 +137,25 @@ int do_cmd(char *cmd,char *machine,char *user,char *path,int *f_in,int *f_out)
   int i,argc=0;
   char *tok,*p;
 
-  if (!cmd)
-    cmd = getenv(RSYNC_RSH_ENV);
-  if (!cmd)
-    cmd = RSYNC_RSH;
-  cmd = strdup(cmd);
-  if (!cmd) 
-    goto oom;
+  if (!local_server) {
+    if (!cmd)
+      cmd = getenv(RSYNC_RSH_ENV);
+    if (!cmd)
+      cmd = RSYNC_RSH;
+    cmd = strdup(cmd);
+    if (!cmd) 
+      goto oom;
 
-  for (tok=strtok(cmd," ");tok;tok=strtok(NULL," ")) {
-    args[argc++] = tok;
-  }
+    for (tok=strtok(cmd," ");tok;tok=strtok(NULL," ")) {
+      args[argc++] = tok;
+    }
 
-  if (user) {
-    args[argc++] = "-l";
-    args[argc++] = user;
+    if (user) {
+      args[argc++] = "-l";
+      args[argc++] = user;
+    }
+    args[argc++] = machine;
   }
-  args[argc++] = machine;
 
   args[argc++] = RSYNC_NAME;
 
@@ -576,21 +579,27 @@ int main(int argc,char *argv[])
 
       p = strchr(argv[argc-1],':');
       if (!p) {
-	usage(stderr);
-	exit(1);
+	local_server = 1;
       }
 
-      *p = 0;
-      shell_machine = argv[argc-1];
-      shell_path = p+1;
+      if (local_server) {
+	shell_machine = NULL;
+	shell_path = argv[argc-1];
+      } else {
+	*p = 0;
+	shell_machine = argv[argc-1];
+	shell_path = p+1;
+      }
       argc--;
     }
 
-    p = strchr(shell_machine,'@');
-    if (p) {
-      *p = 0;
-      shell_user = shell_machine;
-      shell_machine = p+1;
+    if (shell_machine) {
+      p = strchr(shell_machine,'@');
+      if (p) {
+	*p = 0;
+	shell_user = shell_machine;
+	shell_machine = p+1;
+      }
     }
 
     if (verbose > 3) {
